@@ -1,6 +1,6 @@
 """
-Simple functions for storing stuff as textfiles
-on the filesystem.
+A text-based StorageInterface that stores entities
+in the filesystem.
 """
 
 import codecs
@@ -26,8 +26,8 @@ from tiddlyweb.util import LockError, write_lock, write_unlock, \
 
 class Store(StorageInterface):
     """
-    The text-based store on the filesystem in a
-    directory hierarchy implementation of a StorageInterface.
+    A StorageInterface which stores text-based representations
+    in a collection of directories and files.
     """
 
     def __init__(self, store_config=None, environ=None):
@@ -37,8 +37,14 @@ class Store(StorageInterface):
         self._init_store()
 
     def _fixup_root(self, path):
+        """
+        Adjust the store_root path so it is absolute.
+
+        This is required in some web serving environments.
+        """
         if not os.path.isabs(path):
-            path = os.path.join(self.environ['tiddlyweb.config'].get('root_dir', ''), path)
+            path = os.path.join(self.environ['tiddlyweb.config'].
+                    get('root_dir', ''), path)
         return path
 
     def _init_store(self):
@@ -118,15 +124,6 @@ class Store(StorageInterface):
         of its tiddlers.
         """
         bag_path = self._bag_path(bag.name)
-        tiddlers_dir = self._tiddlers_dir(bag.name)
-
-        if not (hasattr(bag, 'skinny') and bag.skinny):
-            try:
-                tiddlers = self._files_in_dir(tiddlers_dir)
-            except (IOError, OSError), exc:
-                raise NoBagError('unable to list tiddlers in bag: %s' % exc)
-            bag.add_tiddlers(Tiddler(urllib.unquote(
-                title).decode('utf-8')) for title in tiddlers)
 
         try:
             bag.desc = self._read_bag_description(bag_path)
@@ -164,7 +161,6 @@ class Store(StorageInterface):
             if not os.path.exists(tiddler_base_filename):
                 raise NoTiddlerError('%s not present' % tiddler_base_filename)
             shutil.rmtree(tiddler_base_filename)
-            self.tiddler_written(tiddler)
         except NoTiddlerError:
             raise
         except Exception, exc:
@@ -228,7 +224,6 @@ class Store(StorageInterface):
         write_utf8_file(tiddler_filename, self.serializer.to_string())
         write_unlock(tiddler_base_filename)
         tiddler.revision = revision
-        self.tiddler_written(tiddler)
 
     def user_delete(self, user):
         """
@@ -301,6 +296,21 @@ class Store(StorageInterface):
 
         return (Bag(urllib.unquote(bag).decode('utf-8')) for bag in bags)
 
+    def list_bag_tiddlers(self, bag):
+        """
+        List all the tiddlers in the provided bag.
+        """
+        tiddlers_dir = self._tiddlers_dir(bag.name)
+
+        try:
+            tiddlers = self._files_in_dir(tiddlers_dir)
+        except (IOError, OSError), exc:
+            raise NoBagError('unable to list tiddlers in bag: %s' % exc)
+        for title in tiddlers:
+            title = urllib.unquote(title).decode('utf-8')
+            tiddler = Tiddler(title, bag.name)
+            yield tiddler
+
     def list_users(self):
         """
         List all the users in the store.
@@ -332,7 +342,6 @@ class Store(StorageInterface):
         This is intentionally simple, slow and broken to encourage overriding.
         """
         bag_filenames = self._bag_filenames()
-        found_tiddlers = []
 
         query = search_query.lower()
 
@@ -347,19 +356,19 @@ class Store(StorageInterface):
                 try:
                     revision_id = self.list_tiddler_revisions(tiddler)[0]
                     if query in tiddler.title.lower():
-                        found_tiddlers.append(tiddler)
+                        yield tiddler
                         continue
                     tiddler_file = codecs.open(
                         self._tiddler_full_filename(tiddler, revision_id),
                         encoding='utf-8')
                     for line in tiddler_file:
                         if query in line.lower():
-                            found_tiddlers.append(tiddler)
+                            yield tiddler
                             break
                 except (OSError, NoTiddlerError), exc:
                     logging.warn('malformed tiddler during search: %s:%s',
                             bagname, tiddler_name)
-        return found_tiddlers
+        return
 
     def _bag_filenames(self):
         """
